=======
History
=======

0.3.2 (2025-03-01)
------------------

* Updated to SPADE 4.0.1
* Updated dependencies
* License changed to MIT

0.3.1 (2024-01-06)
------------------

* Added new examples
* Added documentation
* Updated to SPADE 3.3.2

0.3.0 (2023-06-13)
------------------

* Updated to SPADE 3.3.0.

0.2.2 (2022-06-03)
------------------

* Added exception when belief is not initialized.
* Improved examples.
* Improved documentation.

0.2.1 (2020-04-13)
------------------

* Fixed a bug when updating beliefs.
* Upgraded spade version to 3.1.4.

0.2.0 (2020-02-24)
------------------

* Created add_custom_actions method.
* Added example for actions.
* Improved documentation.
* Added some helpers like pause_bdi, resume_bdi.
* Now the asl file in the constructor is mandatory.

0.1.4 (2019-07-10)
------------------

* Allow to send messages to JIDs stored as beliefs.

0.1.3 (2019-07-08)
------------------

* Allow .send to a list of receivers.
* Allow to receive messages with lists of lists.
* Fixed readme.

0.1.1 (2019-06-18)
------------------

* Moved from pyson to python-agentspeak
* Added some helpers like pause_bdi, resume_bdi.
* Now the asl file in the constructor is mandatory.
* Allow to send tell messages with no args.
* Allow sending messages with variables.
* Extended the examples.

0.1.0 (2019-03-09)
------------------

* First release on PyPI.
